@@ -8,8 +8,8 @@
 #   the GNU Lesser General Public License version 2 or later.
 #
 
-unless defined?(::ParseError) then
-  class ParseError < StandardError ; end
+unless defined? ParseError then
+  class ParseError < StandardError; end
 end
 
 
@@ -36,21 +36,21 @@ class Parser
 
 
   def do_parse
-    unless self.type::DEBUG_PARSER then
+    t = self.type
+    unless t::Racc_debug_parser then
       @yydebug = false
     end
     @yydebug = @yydebug ? true : false
 
-    t = self.type
     send( Racc_Main_Parsing_Routine,
-          t::LR_action_table,
-          t::LR_action_table_ptr,
-          t::LR_goto_table,
-          t::LR_goto_table_ptr,
-          t::LR_reduce_table,
-          t::LR_token_table,
-          t::LR_shift_n,
-          t::LR_reduce_n,
+          t::Racc_action_table,
+          t::Racc_action_table_ptr,
+          t::Racc_goto_table,
+          t::Racc_goto_table_ptr,
+          t::Racc_reduce_table,
+          t::Racc_token_table,
+          t::Racc_shift_n,
+          t::Racc_reduce_n,
           false )
   end
 
@@ -311,7 +311,7 @@ class Parser
   end
 
   def _token2str( tok )
-    unless ret = self.type::TOKEN_TO_S_TABLE[tok] then
+    unless ret = self.type::Racc_token_to_s_table[tok] then
       raise RuntimeError, "[Racc Bug] can't convert token #{tok} to string"
     end
     ret
